@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2013  Victor Efimov
+# Copyright (C) 2012-2014  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -29,8 +29,7 @@ use App::MtAws::ConfigDefinition;
 use App::MtAws::ConfigEngine;
 use Test::More;
 
-require Exporter;
-use base qw/Exporter/;
+use Exporter;
 use Encode;
 use Carp;
 use IO::Pipe;
@@ -42,6 +41,14 @@ our @EXPORT = qw/fake_config config_create_and_parse disable_validations no_disa
 capture_stdout capture_stderr assert_raises_exception ordered_test test_fast_ok fast_ok with_fork
 can_work_with_non_utf8_files get_temp_dir is_iv_without_pv is_posix_root JSON_XS_TRUE JSON_XS_FALSE plan_tests/;
 
+our %SPECIAL_EXPORT = map { $_ => undef } qw/w_fatal/;
+sub import
+{
+	@_ = grep { ! (exists $SPECIAL_EXPORT{$_} && ($SPECIAL_EXPORT{$_} = 1)) } @_;
+	warning_fatal() if ($SPECIAL_EXPORT{w_fatal}) ; # compile time warnings fatal
+	goto &Exporter::import;
+}
+
 use Test::Deep; # should be last line, after EXPORT stuff, otherwise versions ^(0\.089|0\.09[0-9].*) do something nastly with exports
 
 use constant ALARM_FOR_FORK_TESTS => 30;
@@ -51,6 +58,7 @@ use constant ALARM_FOR_FORK_TESTS => 30;
 use constant JSON_XS_TRUE => \1;
 use constant JSON_XS_FALSE => \0;
 
+# run time or compile time warnings fatal
 sub warning_fatal
 {
 	my ($skip_re) = @_;
